<?php
namespace app\admin\controller;
use think\captcha\Captcha;
use think\Config;
use think\Request;
use app\admin\model\Admin as AdminModel;

/**
 * Created by PhpStorm.
 * User: Administrator
 * Date: 2017/11/30
 * Time: 11:46
 */
class Admin extends BaseController{
    protected $model_admin;
    public function __construct(Request $request = null){
        parent::__construct($request);
        $this->model_admin = new AdminModel();
    }

    /**
     * 跳转到登录页面
     */
    public function login(){
        $param = input('post.');
        if($param){
            $validate = [
                'username' => 'require',
                'password' => 'require',
                'code' => 'require'
            ];
            $message = [
                'username' => '请填写账号',
                'password' => '请填写密码',
                'code' => '请填写验证码'
            ];
            $res = $this->validate($param, $validate, $message);
            if(true !== $res){
                return json(array('status'=>-1, 'msg'=>$res));
            }
            if(!$this->check_verify($param['code'])){
                return json(array('status'=>-1, 'msg'=>'验证码不正确'));
            }
            $where = [
                'username' => $param['username']
            ];
            $vo = $this->model_admin->where($where)->find();
            if($vo){
                if(decrypt_password($param['password'], $vo['password'])){
                    $userInfo = [
                        'uid' => $vo['id'],
                        'username' => $vo['username']
                    ];
                    session('admin_info', $userInfo);
                    return json(array('status'=>1, 'msg'=>'登录成功'));
                }
            }
            return json(array('status'=>-1, 'msg'=>'账号或密码不正确'));
        }
        return $this->fetch();
    }

    /**
     * 获取验证码
     */
    public function vertify(){
        $config = Config::get('vertify_code');
        $captcha = new Captcha($config);
        return $captcha->entry();
    }

    /**
     * 验证验证码
     * @param $code 验证码
     * @param string $id 多个验证码标识
     * @return bool 验证码是否正确
     */
    function check_verify($code, $id = ''){
        $captcha = new Captcha(['reset'=>false]);
        return $captcha->check($code, $id);
    }

    /**
     * 登录成功页面跳转
     */
    function check_success(){
        $this->success('登录成功,页面跳转中...',url('index/index'));
    }

    /**
     * 修改管理员信息
     */
    function change_admin(){
        $param = input('post.');
        $validate = $this->validate($param,
            [
                'old_password'=>'require',
                'new_username'=>'require',
                'new_password'=>'require'
            ],[
                'old_password'=>'请填写当前密码',
                'new_username'=>'请填写新的账号',
                'new_password'=>'请填写新的密码'
            ]);
        if(true !== $validate){
            return json(['status'=>-1,'msg'=>$validate]);
        }
        $user_info = session('admin_info');
        $uid = $user_info['uid'];
        $vo = $this->model_admin->where(['id'=>$uid])->find();
        if($vo){
            if(decrypt_password($param['old_password'], $vo['password'])){
                $new_vo['username'] = $param['new_username'];
                $new_vo['password'] = encrypt_password($param['new_password']);
                $num = $this->model_admin->save($new_vo,['id'=>$vo['id']]);
                if($num){
                    session(null);
                    return json(array('status'=>1, 'msg'=>'保存成功', 'url'=>url('admin/login')));
                }else{
                    return json(array('status'=>-1, 'msg'=>'保存失败'));
                }
            }else{
                return json(array('status'=>-1, 'msg'=>'当前密码不正确'));
            }
        }
        return json(array('status'=>-1, 'msg'=>'账号或密码不正确'));
    }

    /**
     * 管理员退出
     */
    public function logout(){
        session(null);
        return $this->redirect(url('admin/login'));
    }
}